@@ -70,6 +70,7 @@ import github.Topic
 from . import (
     AuthenticatedUser,
     Consts,
+    GithubApp,
     GithubException,
     GitignoreTemplate,
     HookDescription,
@@ -274,6 +275,20 @@ class Github(object):
                 self.__requester, headers, data, completed=True
             )
 
+    def get_user_by_id(self, user_id):
+        """
+        :calls: `GET /user/:id <http://developer.github.com/v3/users>`_
+        :param user_id: int
+        :rtype: :class:`github.NamedUser.NamedUser`
+        """
+        assert isinstance(user_id, int), user_id
+        headers, data = self.__requester.requestJsonAndCheck(
+            "GET", "/user/" + str(user_id)
+        )
+        return github.NamedUser.NamedUser(
+            self.__requester, headers, data, completed=True
+        )
+
     def get_users(self, since=github.GithubObject.NotSet):
         """
         :calls: `GET /users <http://developer.github.com/v3/users>`_
@@ -770,16 +785,6 @@ class Github(object):
         """
         return self.create_from_raw_data(*pickle.load(f))
 
-    def get_installation(self, id):
-        """
-
-        :param id:
-        :return:
-        """
-        return Installation.Installation(
-            self.__requester, headers={}, attributes={"id": id}, completed=True
-        )
-
     def get_oauth_application(self, client_id, client_secret):
         return github.ApplicationOAuth.ApplicationOAuth(
             self.__requester,
@@ -788,6 +793,21 @@ class Github(object):
             completed=False,
         )
 
+    def get_app(self, slug=github.GithubObject.NotSet):
+        """
+        :calls: `GET /apps/:slug <https://docs.github.com/en/rest/reference/apps>`_ or `GET /app <https://docs.github.com/en/rest/reference/apps>`_
+        :param slug: string
+        :rtype: :class:`github.GithubApp.GithubApp`
+        """
+        assert slug is github.GithubObject.NotSet or isinstance(slug, str), slug
+        if slug is github.GithubObject.NotSet:
+            return GithubApp.GithubApp(
+                self.__requester, {}, {"url": "/app"}, completed=False
+            )
+        else:
+            headers, data = self.__requester.requestJsonAndCheck("GET", "/apps/" + slug)
+            return GithubApp.GithubApp(self.__requester, headers, data, completed=True)
+
 
 class GithubIntegration(object):
     """
