@@ -1156,6 +1156,21 @@ class Organization(github.GithubObject.CompletableGithubObject):
             headers={"Accept": Consts.mediaTypeMigrationPreview},
         )
 
+    def get_installations(self):
+        """
+        :calls: `GET /orgs/:org/installations <https://developer.github.com/v3/orgs/#list-app-installations-for-an-organization>`_
+        :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Installation.Installation`
+        """
+
+        return github.PaginatedList.PaginatedList(
+            github.Installation.Installation,
+            self._requester,
+            self.url + "/installations",
+            None,
+            None,
+            list_item="installations",
+        )
+
     def _initAttributes(self):
         self._default_repository_permission = github.GithubObject.NotSet
         self._has_organization_projects = github.GithubObject.NotSet
